@@ -1,6 +1,7 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
     SPDX-FileCopyrightText: 2009 Alexander Rieder <alexanderrieder@gmail.com>
+    SPDX-FileCopyrightText: 2018-2022 by Alexander Semke (alexander.semke@web.de)
 */
 
 #ifndef _TESTMAXIMA_H
@@ -28,28 +29,36 @@ private Q_SLOTS:
     void testPlot();
     void testPlotWithAnotherTextResults();
 
+    /* errors and warnings */
+
     //tests a syntax error (not closing bracket)
     void testInvalidSyntax();
+    void testWarning01();
+    void testWarning02();
     //tests if the expression numbering works
     void testExprNumbering();
+    void testInvalidAssignment();
 
-    //some tests to see if comments are working correctly
+    /* comments */
     void testSimpleExpressionWithComment();
     void testCommentExpression();
     void testNestedComment();
     void testUnmatchedComment();
 
-    void testInvalidAssignment();
-
+    /* tests where additional input is required */
     void testInformationRequest();
     void testHelpRequest();
     void testSyntaxHelp();
+
     void testCompletion();
 
     void testVariableModel();
 
+    void testLispMode01();
+
     void testLoginLogout();
     void testRestartWhileRunning();
+
 private:
     QString backendName() override;
 };
