@@ -236,12 +236,8 @@ CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QVariantLi
 
     m_typeset = new KToggleAction(i18n("Typeset using LaTeX"), collection);
     m_typeset->setChecked(Settings::self()->typesetDefault());
-    // Disable until login, because we use session command for this action
-    m_typeset->setEnabled(false);
     collection->addAction(QLatin1String("enable_typesetting"), m_typeset);
     connect(m_typeset, &KToggleAction::toggled, this, &CantorPart::enableTypesetting);
-    if (!Cantor::LatexRenderer::isLatexAvailable())
-        m_typeset->setVisible(false);
 
     m_highlight = new KToggleAction(i18n("Syntax Highlighting"), collection);
     m_highlight->setChecked(Settings::self()->highlightDefault());
@@ -357,10 +353,8 @@ CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QVariantLi
 
     QAction* showCompletion = new QAction(i18n("Show Completion"), collection);
     collection->addAction(QLatin1String("show_completion"), showCompletion);
-    QList<QKeySequence> showCompletionShortcuts;
-    showCompletionShortcuts << Qt::CTRL + Qt::Key_Space; // No Tab, because the tab handeled by entries itself
-    collection->setDefaultShortcuts(showCompletion, showCompletionShortcuts);
-    connect(showCompletion, SIGNAL(triggered()), m_worksheet, SLOT(showCompletion()));
+    collection->setDefaultShortcut(showCompletion, Qt::CTRL + Qt::Key_Space);
+    connect(showCompletion, &QAction::triggered, m_worksheet, &Worksheet::showCompletion);
     m_editActions.push_back(showCompletion);
 
     // set our XML-UI resource file
@@ -715,10 +709,7 @@ void CantorPart::worksheetSessionLoginStarted() {
 
 void CantorPart::worksheetSessionLoginDone() {
     setStatusMessage(i18n("Ready"));
-
-    m_typeset->setEnabled(true);
     m_restart->setEnabled(true);
-
     QApplication::restoreOverrideCursor();
 }
 
@@ -736,7 +727,7 @@ void CantorPart::enableTypesetting(bool enable)
  */
 void CantorPart::documentationRequested(const QString& keyword) {
     auto* backend = m_worksheet->session()->backend();
-    const KConfigGroup& group = KSharedConfig::openConfig()->group(backend->name().toLower());
+    const auto& group = KSharedConfig::openConfig(QStringLiteral("cantorrc"))->group(backend->name().toLower());
     const auto& docNames = group.readEntry(QLatin1String("Names"), QStringList());
     if (!docNames.isEmpty())
         emit requestDocumentation(keyword);
