@@ -151,6 +151,7 @@ protected Q_SLOTS:
         where set during the block
     **/
     void unblockStatusBar();
+
 private:
     Worksheet *m_worksheet;
     WorksheetView *m_worksheetview;
@@ -172,12 +173,14 @@ private:
     KToggleAction* m_exprNumbering;
     KToggleAction* m_animateWorksheet;
     KToggleAction* m_embeddedMath;
-    QAction * m_showBackendHelp;
     QVector<QAction*> m_editActions;
 
     QString m_cachedStatusMessage;
     bool m_statusBarBlocked;
     unsigned int m_sessionStatusCounter;
+
+private Q_SLOTS:
+    void documentationRequested(const QString&);
 };
 
 #endif // CANTORPART_H
